API Documentation
*****************


.. contents:: Contents
   :local:

jira package
============

jira.client module
------------------

.. automodule:: jira.client
   :members:
   :undoc-members:
   :show-inheritance:

jira.config module
------------------

.. automodule:: jira.config
   :members:
   :undoc-members:
   :show-inheritance:

jira.exceptions module
----------------------

.. automodule:: jira.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

jira.jirashell module
---------------------

.. automodule:: jira.jirashell
   :members:
   :undoc-members:
   :show-inheritance:

jira.resilientsession module
----------------------------

.. automodule:: jira.resilientsession
   :members:
   :undoc-members:
   :show-inheritance:

jira.resources module
---------------------

.. autodata:: jira.client.ResourceType
   :annotation: = alias of TypeVar(‘ResourceType’, contravariant=True, bound=jira.resources.Resource)

.. automodule:: jira.resources
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:

.. autoclass:: jira.resources.StatusCategory
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: jira.resources.GreenHopperResource
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: jira.resources.Sprint
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: jira.resources.Board
   :members:
   :undoc-members:
   :show-inheritance:


jira.utils module
-----------------

.. automodule:: jira.utils
   :members:
   :undoc-members:
   :show-inheritance:
